# Базовый пример MCP Microservice

Этот пример демонстрирует базовую функциональность MCP Microservice с несколькими командами,
организованными в отдельные файлы.

## Структура

```
basic_example/
├── commands/                   # Директория с командами
│   ├── __init__.py            # Инициализация пакета
│   ├── echo_command.py        # Команда эхо
│   ├── math_command.py        # Математическая команда
│   └── time_command.py        # Команда времени
├── config.json                # Файл конфигурации JSON
├── docs/                      # Документация
│   ├── EN/                    # Английская документация
│   │   └── README.md          # Английская версия данного файла
│   └── RU/                    # Русская документация
│       └── README.md          # Этот файл
├── logs/                      # Директория для логов
├── server.py                  # Файл запуска сервера и логики приложения
└── tests/                     # Директория с тестами
    └── conftest.py            # Конфигурация и фикстуры для тестов
```

## Запуск примера

```bash
# Перейти в директорию проекта
cd examples/basic_example

# Создать директорию для логов, если она не существует
mkdir -p logs

# Запустить сервер с конфигурацией по умолчанию (config.json)
python server.py

# Или запустить с указанием другого файла конфигурации
python server.py --config другой_конфиг.json
```

После запуска сервер будет доступен по адресу [http://localhost:8000](http://localhost:8000).

## Конфигурация

Сервер считывает конфигурацию из JSON-файлов. По умолчанию используется `config.json` в том же каталоге, где находится `server.py`.

Вы можете указать другой файл конфигурации с помощью параметра `--config`:

```bash
python server.py --config мой_конфиг.json
```

Если указанный файл конфигурации не существует, сервер попытается использовать `config.json`.

Основные параметры конфигурации:

```json
{
  "server": {
    "host": "0.0.0.0",
    "port": 8000,
    "debug": true,
    "log_level": "info"
  },
  "logging": {
    "level": "INFO",
    "file": "logs/basic_example.log"
  }
}
```

Сервер может работать в двух режимах:
- Обычный режим: использует предварительно настроенный экземпляр приложения
- Режим отладки: использует горячую перезагрузку (когда `"debug": true` в конфигурации)

## Доступные команды

### 1. `echo` - Эхо-команда

Возвращает переданное сообщение.

**Параметры:**
- `message` (string) - Сообщение для эхо

**Пример запроса:**
```json
{
  "jsonrpc": "2.0",
  "method": "echo",
  "params": {
    "message": "Hello, World!"
  },
  "id": 1
}
```

### 2. `math` - Математическая команда

Выполняет математическую операцию над двумя числами.

**Параметры:**
- `a` (number) - Первое число
- `b` (number) - Второе число
- `operation` (string) - Операция (add, subtract, multiply, divide)

**Пример запроса:**
```json
{
  "jsonrpc": "2.0",
  "method": "math",
  "params": {
    "a": 10,
    "b": 5,
    "operation": "add"
  },
  "id": 1
}
```

### 3. `time` - Команда времени

Возвращает текущее время и дату.

**Параметры:**
- `format` (string, опционально) - Формат времени (по умолчанию: "%Y-%m-%d %H:%M:%S")
- `timezone` (string, опционально) - Часовой пояс (по умолчанию: "UTC")

**Пример запроса:**
```json
{
  "jsonrpc": "2.0",
  "method": "time",
  "params": {
    "format": "%d.%m.%Y %H:%M:%S",
    "timezone": "Europe/Moscow"
  },
  "id": 1
}
```

## Тестирование API

### Через веб-интерфейс

Откройте в браузере [http://localhost:8000/docs](http://localhost:8000/docs) для доступа к интерактивной документации Swagger UI.

### Через командную строку

```bash
# Вызов команды echo через JSON-RPC
curl -X POST "http://localhost:8000/api/jsonrpc" \
  -H "Content-Type: application/json" \
  -d '{"jsonrpc": "2.0", "method": "echo", "params": {"message": "Hello!"}, "id": 1}'

# Вызов команды math через упрощенный эндпоинт
curl -X POST "http://localhost:8000/cmd" \
  -H "Content-Type: application/json" \
  -d '{"command": "math", "params": {"a": 10, "b": 5, "operation": "add"}}'

# Вызов команды time через endpoint /api/command/{command_name}
curl -X POST "http://localhost:8000/api/command/time" \
  -H "Content-Type: application/json" \
  -d '{"format": "%d.%m.%Y %H:%M:%S", "timezone": "UTC"}'
```

## Ключевые особенности, демонстрируемые примером

1. Организация команд в отдельные файлы
2. Автоматическое обнаружение и регистрация команд
3. Различные типы команд и параметров
4. Обработка ошибок и автоматическая перерегистрация команд
5. Различные способы вызова команд (JSON-RPC, /cmd, /api/command/{command_name})
6. Поддержка режима отладки с горячей перезагрузкой
7. Безопасная регистрация команд для предотвращения конфликтов
8. JSON-файлы конфигурации с опциями командной строки 